@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -48,9 +49,7 @@
 #include <svx/zoomslideritem.hxx>
 #include <svl/eitem.hxx>
 
-#ifndef _SVX_DIALOGS_HRC
 #include <svx/dialogs.hrc>
-#endif
 #include <svx/extrusionbar.hxx>
 #include <svx/fontworkbar.hxx>
 #include <svx/clipfmtitem.hxx>
@@ -61,6 +60,7 @@
 #include <sfx2/dispatch.hxx>
 #include <svtools/cliplistener.hxx>
 #include <svx/float3d.hxx>
+#include "helpids.h"
 
 #include "view/viewoverlaymanager.hxx"
 #include "app.hrc"
@@ -89,12 +89,12 @@ using namespace ::com::sun::star::uno;
 
 namespace {
 static const ::rtl::OUString MASTER_VIEW_TOOL_BAR_NAME(
-    ::rtl::OUString::createFromAscii("masterviewtoolbar"));
+    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("masterviewtoolbar")));
 }
 
 namespace sd {
 
-BOOL DrawViewShell::mbPipette = FALSE;
+sal_Bool DrawViewShell::mbPipette = sal_False;
 
 // ------------------------
 // - ScannerEventListener -
@@ -140,6 +140,7 @@ void SAL_CALL ScannerEventListener::disposing( const ::com::sun::star::lang::Eve
 DrawViewShell::DrawViewShell( SfxViewFrame* pFrame, ViewShellBase& rViewShellBase, ::Window* pParentWindow, PageKind ePageKind, FrameView* pFrameViewArgument )
 : ViewShell (pFrame, pParentWindow, rViewShellBase)
 , maTabControl(this, pParentWindow)
+, mbIsLayerModeActive(false)
 , mbIsInSwitchPage(false)
 {
     if (pFrameViewArgument != NULL)
@@ -165,9 +166,9 @@ DrawViewShell::~DrawViewShell()
     if( mxScannerListener.is() )
         static_cast< ScannerEventListener* >( mxScannerListener.get() )->ParentDestroyed();
 
-    // #96642# Remove references to items within Svx3DWin
+    // Remove references to items within Svx3DWin
     // (maybe do a listening sometime in Svx3DWin)
-    USHORT nId = Svx3DChildWindow::GetChildWindowId();
+    sal_uInt16 nId = Svx3DChildWindow::GetChildWindowId();
     SfxChildWindow* pWindow = GetViewFrame() ? GetViewFrame()->GetChildWindow(nId) : NULL;
     if(pWindow)
     {
@@ -185,26 +186,26 @@ DrawViewShell::~DrawViewShell()
     DisposeFunctions();
 
     SdPage* pPage;
-    USHORT aPageCnt = GetDoc()->GetSdPageCount(mePageKind);
+    sal_uInt16 aPageCnt = GetDoc()->GetSdPageCount(mePageKind);
 
-    for (USHORT i = 0; i < aPageCnt; i++)
+    for (sal_uInt16 i = 0; i < aPageCnt; i++)
     {
         pPage = GetDoc()->GetSdPage(i, mePageKind);
 
         if (pPage == mpActualPage)
         {
-            GetDoc()->SetSelected(pPage, TRUE);
+            GetDoc()->SetSelected(pPage, sal_True);
         }
         else
         {
-            GetDoc()->SetSelected(pPage, FALSE);
+            GetDoc()->SetSelected(pPage, sal_False);
         }
     }
 
     if ( mpClipEvtLstnr )
     {
-        mpClipEvtLstnr->AddRemoveListener( GetActiveWindow(), FALSE );
-        mpClipEvtLstnr->ClearCallbackLink();		// #103849# prevent callback if another thread is waiting
+        mpClipEvtLstnr->AddRemoveListener( GetActiveWindow(), sal_False );
+        mpClipEvtLstnr->ClearCallbackLink();		// prevent callback if another thread is waiting
         mpClipEvtLstnr->release();
     }
 
@@ -226,11 +227,11 @@ DrawViewShell::~DrawViewShell()
 void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
 {
     mpActualPage = 0;
-    mbMousePosFreezed = FALSE;
+    mbMousePosFreezed = sal_False;
     mbReadOnly = GetDocSh()->IsReadOnly();
     mpSlotArray = 0;
     mpClipEvtLstnr = 0;
-    mbPastePossible = FALSE;
+    mbPastePossible = sal_False;
     mbIsLayerModeActive = false;
 
     mpFrameView->Connect();
@@ -242,7 +243,7 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
     // Ungerader Eintrag: gemappter Slot
     // Achtung: Anpassen von GetIdBySubId() !!!
     // Reihenfolge (insbesondere Zoom) darf nicht geaendert werden !!!
-    mpSlotArray = new USHORT[ SLOTARRAY_COUNT ];
+    mpSlotArray = new sal_uInt16[ SLOTARRAY_COUNT ];
     mpSlotArray[ 0 ]  = SID_OBJECT_CHOOSE_MODE;
     mpSlotArray[ 1 ]  = SID_OBJECT_ROTATE;
     mpSlotArray[ 2 ]  = SID_OBJECT_ALIGN;
@@ -274,7 +275,7 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
 
     mpDrawView = new DrawView(pDocSh, GetActiveWindow(), this);
     mpView = mpDrawView;			 // Pointer der Basisklasse ViewShell
-    mpDrawView->SetSwapAsynchron(TRUE); // Asynchrones Laden von Graphiken
+    mpDrawView->SetSwapAsynchron(sal_True); // Asynchrones Laden von Graphiken
 
     // We do not read the page kind from the frame view anymore so we have
     // to set it in order to resync frame view and this view.
@@ -334,16 +335,16 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
     if( eDocType == DOCUMENT_TYPE_DRAW )
     {
         SetHelpId( SD_IF_SDGRAPHICVIEWSHELL );
-        GetActiveWindow()->SetHelpId( SD_IF_SDGRAPHICVIEWSHELL );
-        GetActiveWindow()->SetUniqueId( SD_IF_SDGRAPHICVIEWSHELL );
+        GetActiveWindow()->SetHelpId( HID_SDGRAPHICVIEWSHELL );
+        GetActiveWindow()->SetUniqueId( HID_SDGRAPHICVIEWSHELL );
     }
     else
     {
         if (mePageKind == PK_NOTES)
         {
             SetHelpId( SID_NOTESMODE );
-            GetActiveWindow()->SetHelpId( SID_NOTESMODE );
-            GetActiveWindow()->SetUniqueId( SID_NOTESMODE );
+            GetActiveWindow()->SetHelpId( CMD_SID_NOTESMODE );
+            GetActiveWindow()->SetUniqueId( CMD_SID_NOTESMODE );
 
             // AutoLayouts muessen erzeugt sein
             GetDoc()->StopWorkStartupDelay();
@@ -351,8 +352,8 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
         else if (mePageKind == PK_HANDOUT)
         {
             SetHelpId( SID_HANDOUTMODE );
-            GetActiveWindow()->SetHelpId( SID_HANDOUTMODE );
-            GetActiveWindow()->SetUniqueId( SID_HANDOUTMODE );
+            GetActiveWindow()->SetHelpId( CMD_SID_HANDOUTMODE );
+            GetActiveWindow()->SetUniqueId( CMD_SID_HANDOUTMODE );
 
             // AutoLayouts muessen erzeugt sein
             GetDoc()->StopWorkStartupDelay();
@@ -360,26 +361,26 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
         else
         {
             SetHelpId( SD_IF_SDDRAWVIEWSHELL );
-            GetActiveWindow()->SetHelpId( SD_IF_SDDRAWVIEWSHELL );
-            GetActiveWindow()->SetUniqueId( SD_IF_SDDRAWVIEWSHELL );
+            GetActiveWindow()->SetHelpId( HID_SDDRAWVIEWSHELL );
+            GetActiveWindow()->SetUniqueId( HID_SDDRAWVIEWSHELL );
         }
     }
 
     // Selektionsfunktion starten
     SfxRequest aReq(SID_OBJECT_SELECT, 0, GetDoc()->GetItemPool());
     FuPermanent(aReq);
-    mpDrawView->SetFrameDragSingles(TRUE);
+    mpDrawView->SetFrameDragSingles(sal_True);
 
     if (pDocSh->GetCreateMode() == SFX_CREATE_MODE_EMBEDDED)
     {
-        mbZoomOnPage = FALSE;
+        mbZoomOnPage = sal_False;
     }
     else
     {
-        mbZoomOnPage = TRUE;
+        mbZoomOnPage = sal_True;
     }
 
-    mbIsRulerDrag = FALSE;
+    mbIsRulerDrag = sal_False;
 
     String aName( RTL_CONSTASCII_USTRINGPARAM("DrawViewShell"));
     SetName (aName);
@@ -391,7 +392,7 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
     if( xMgr.is() )
     {
         mxScannerManager = ::com::sun::star::uno::Reference< ::com::sun::star::scanner::XScannerManager >(
-                           xMgr->createInstance( ::rtl::OUString::createFromAscii( "com.sun.star.scanner.ScannerManager" ) ),
+                           xMgr->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.scanner.ScannerManager" )) ),
                            ::com::sun::star::uno::UNO_QUERY );
 
         if( mxScannerManager.is() )
@@ -492,7 +493,7 @@ void DrawViewShell::CheckLineTo(SfxRequest& rReq)
     {
         if(SID_LINETO == rReq.GetSlot() || SID_BEZIERTO == rReq.GetSlot() || SID_MOVETO == rReq.GetSlot() )
         {
-            DBG_ERROR("DrawViewShell::CheckLineTo: slots SID_LINETO, SID_BEZIERTO, SID_MOVETO no longer supported.");
+            OSL_FAIL("DrawViewShell::CheckLineTo: slots SID_LINETO, SID_BEZIERTO, SID_MOVETO no longer supported.");
         }
     }
 #endif
@@ -511,12 +512,12 @@ void DrawViewShell::SetupPage (Size &rSize,
                                  long nRight,
                                  long nUpper,
                                  long nLower,
-                                 BOOL bSize,
-                                 BOOL bMargin,
-                                 BOOL bScaleAll)
+                                 sal_Bool bSize,
+                                 sal_Bool bMargin,
+                                 sal_Bool bScaleAll)
 {
-    USHORT nPageCnt = GetDoc()->GetMasterSdPageCount(mePageKind);
-    USHORT i;
+    sal_uInt16 nPageCnt = GetDoc()->GetMasterSdPageCount(mePageKind);
+    sal_uInt16 i;
 
     for (i = 0; i < nPageCnt; i++)
     {
@@ -589,7 +590,7 @@ void DrawViewShell::SetupPage (Size &rSize,
     if ( mePageKind == PK_STANDARD )
     {
         SdPage* pHandoutPage = GetDoc()->GetSdPage(0, PK_HANDOUT);
-        pHandoutPage->CreateTitleAndLayout(TRUE);
+        pHandoutPage->CreateTitleAndLayout(sal_True);
     }
 
     long nWidth = mpActualPage->GetSize().Width();
@@ -598,7 +599,7 @@ void DrawViewShell::SetupPage (Size &rSize,
     Point aPageOrg(nWidth, nHeight / 2);
     Size aSize( nWidth * 3, nHeight * 2);
 
-    InitWindows(aPageOrg, aSize, Point(-1, -1), TRUE);
+    InitWindows(aPageOrg, aSize, Point(-1, -1), sal_True);
 
     Point aVisAreaPos;
 
@@ -641,7 +642,7 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
         else
         {
             SvxZoomItem* pZoomItem;
-            UINT16 nZoom = (UINT16) GetActiveWindow()->GetZoom();
+            sal_uInt16 nZoom = (sal_uInt16) GetActiveWindow()->GetZoom();
 
             if( mbZoomOnPage )
                 pZoomItem = new SvxZoomItem( SVX_ZOOM_WHOLEPAGE, nZoom );
@@ -649,7 +650,7 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
                 pZoomItem = new SvxZoomItem( SVX_ZOOM_PERCENT, nZoom );
 
             // Bereich einschraenken
-            USHORT nZoomValues = SVX_ZOOM_ENABLE_ALL;
+            sal_uInt16 nZoomValues = SVX_ZOOM_ENABLE_ALL;
             SdrPageView* pPageView = mpDrawView->GetSdrPageView();
 
             if( ( pPageView && pPageView->GetObjList()->GetObjCount() == 0 ) )
@@ -673,7 +674,7 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
         else
         {
             sd::Window * pActiveWindow = GetActiveWindow();
-            SvxZoomSliderItem aZoomItem( (UINT16) pActiveWindow->GetZoom(), (USHORT)pActiveWindow->GetMinZoom(), (USHORT)pActiveWindow->GetMaxZoom() ) ;
+            SvxZoomSliderItem aZoomItem( (sal_uInt16) pActiveWindow->GetZoom(), (sal_uInt16)pActiveWindow->GetMinZoom(), (sal_uInt16)pActiveWindow->GetMaxZoom() ) ;
 
             SdrPageView* pPageView = mpDrawView->GetSdrPageView();
             if( pPageView )
@@ -770,13 +771,13 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
             SdrLayer*  pLayer = NULL;
             SdrObject* pObj = NULL;
             const SdrMarkList& rMarkList = mpDrawView->GetMarkedObjectList();
-            ULONG nMarkCount = rMarkList.GetMarkCount();
-            FASTBOOL bOneLayer = TRUE;
+            sal_uLong nMarkCount = rMarkList.GetMarkCount();
+            bool bOneLayer = true;
 
             // Use the first ten selected shapes as a (hopefully
             // representative) sample of all shapes of the current page.
             // Detect whether they belong to the same layer.
-            for( ULONG j = 0; j < nMarkCount && bOneLayer && j < 10; j++ )
+            for( sal_uLong j = 0; j < nMarkCount && bOneLayer && j < 10; j++ )
             {
                 pObj = rMarkList.GetMark( j )->GetMarkedSdrObj();
                 if( pObj )
@@ -784,7 +785,7 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
                     nLayer = pObj->GetLayer();
 
                     if( j != 0 && nLayer != nOldLayer )
-                        bOneLayer = FALSE;
+                        bOneLayer = sal_False;
 
                     nOldLayer = nLayer;
                 }
@@ -857,3 +858,5 @@ void DrawViewShell::GetAnnotationState (SfxItemSet& rItemSet )
 
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
