@@ -57,15 +57,13 @@ TYPEINIT1(ModifyPageUndoAction, SdUndoAction);
 \************************************************************************/
 
 ModifyPageUndoAction::ModifyPageUndoAction(
-    SfxUndoManager* pTheManager, // #67720#
     SdDrawDocument* pTheDoc,
     SdPage* pThePage,
     String aTheNewName,
     AutoLayout	eTheNewAutoLayout,
-    BOOL bTheNewBckgrndVisible,
-    BOOL bTheNewBckgrndObjsVisible)
-:	SdUndoAction(pTheDoc),
-    mpManager(pTheManager)
+    sal_Bool bTheNewBckgrndVisible,
+    sal_Bool bTheNewBckgrndObjsVisible)
+:	SdUndoAction(pTheDoc)
 {
     DBG_ASSERT(pThePage, "Undo ohne Seite ???");
 
@@ -81,8 +79,8 @@ ModifyPageUndoAction::ModifyPageUndoAction(
     {
         maOldName = mpPage->GetName();
         SdrLayerAdmin& rLayerAdmin = mpDoc->GetLayerAdmin();
-        BYTE aBckgrnd = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRND)), FALSE);
-        BYTE aBckgrndObj = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRNDOBJ)), FALSE);
+        sal_uInt8 aBckgrnd = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRND)), sal_False);
+        sal_uInt8 aBckgrndObj = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRNDOBJ)), sal_False);
         SetOfByte aVisibleLayers = mpPage->TRG_GetMasterPageVisibleLayers();
 
         mbOldBckgrndVisible = aVisibleLayers.IsSet(aBckgrnd);
@@ -101,7 +99,7 @@ ModifyPageUndoAction::ModifyPageUndoAction(
 #include <svx/svdview.hxx>
 void ModifyPageUndoAction::Undo()
 {
-    // #94637# invalidate Selection, there could be objects deleted in tis UNDO
+    // invalidate Selection, there could be objects deleted in tis UNDO
     // which are no longer allowed to be selected then.
       SdrViewIter aIter(mpPage);
     SdrView* pView = aIter.FirstView();
@@ -129,8 +127,8 @@ void ModifyPageUndoAction::Undo()
         }
 
         SdrLayerAdmin& rLayerAdmin = mpDoc->GetLayerAdmin();
-        BYTE aBckgrnd = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRND)), FALSE);
-        BYTE aBckgrndObj = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRNDOBJ)), FALSE);
+        sal_uInt8 aBckgrnd = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRND)), sal_False);
+        sal_uInt8 aBckgrndObj = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRNDOBJ)), sal_False);
         SetOfByte aVisibleLayers;
         aVisibleLayers.Set(aBckgrnd, mbOldBckgrndVisible);
         aVisibleLayers.Set(aBckgrndObj, mbOldBckgrndObjsVisible);
@@ -150,7 +148,7 @@ void ModifyPageUndoAction::Undo()
 
 void ModifyPageUndoAction::Redo()
 {
-    // #94637# invalidate Selection, there could be objects deleted in tis UNDO
+    // invalidate Selection, there could be objects deleted in tis UNDO
     // which are no longer allowed to be selected then.
       SdrViewIter aIter(mpPage);
     SdrView* pView = aIter.FirstView();
@@ -178,8 +176,8 @@ void ModifyPageUndoAction::Redo()
         }
 
         SdrLayerAdmin& rLayerAdmin = mpDoc->GetLayerAdmin();
-        BYTE aBckgrnd = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRND)), FALSE);
-        BYTE aBckgrndObj = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRNDOBJ)), FALSE);
+        sal_uInt8 aBckgrnd = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRND)), sal_False);
+        sal_uInt8 aBckgrndObj = rLayerAdmin.GetLayerID(String(SdResId(STR_LAYER_BCKGRNDOBJ)), sal_False);
         SetOfByte aVisibleLayers;
         aVisibleLayers.Set(aBckgrnd, mbNewBckgrndVisible);
         aVisibleLayers.Set(aBckgrndObj, mbNewBckgrndObjsVisible);
@@ -220,8 +218,8 @@ RenameLayoutTemplateUndoAction::RenameLayoutTemplateUndoAction( SdDrawDocument*
 , maNewName( rNewLayoutName )
 , maComment(SdResId(STR_TITLE_RENAMESLIDE))
 {
-    USHORT nPos = maOldName.SearchAscii( SD_LT_SEPARATOR );
-    if( nPos != (USHORT)-1 )
+    sal_uInt16 nPos = maOldName.SearchAscii( SD_LT_SEPARATOR );
+    if( nPos != (sal_uInt16)-1 )
         maOldName.Erase(nPos);
 }
 
